<?php

namespace Espo\Modules\RealEstate\Hooks\RealEstateProperty;

class EmailRequester extends \Espo\Core\Hooks\Base
{
    public static $order = 16;

    protected function init()
    {
        $this->addDependency('serviceFactory');
    }

    protected function getServiceFactory()
    {
        return $this->getInjection('serviceFactory');
    }

    public function afterSave($entity)
    {
        if (!$this->getConfig()->get('realEstateEmailSending')) return;
        if (!$entity->get('type')) return;

        $toSend = $entity->isNew();

        $fieldList = [
            'type',
            'propertyType',
            'locationId',
            'price'
        ];

        foreach (
            $this->getMetadata()->get(['entityDefs', 'RealEstateProperty', 'propertyTypes', $entity->get('type'), 'fieldList'], [])
            as
            $field
        ) {
            $fieldList[] = $field;
        }


        if (!$toSend) {
            foreach ($fieldList as $field) {
                if ($entity->hasFetched($field) && $entity->isAttributeChanged($field)) {
                    $toSend = true;
                    break;
                }
            }
        }

        if ($toSend) {
            $job = $this->getEntityManager()->getEntity('Job');
            $job->set([
                'serviceName' => 'RealEstateSendMatches',
                'methodName' => 'processPropertyJob',
                'data' => [
                    'targetId' => $entity->id,
                    'isUpdated' => !$entity->isNew()
                ]
            ]);
            $this->getEntityManager()->saveEntity($job);
        }
    }
}
